==> 0.0.5.tar.gz: lib/hyperkyc_result.dart <==
import 'package:hyperkyc_flutter/hyperkyc_flutter_constants.dart';

import 'hyperkyc_data.dart';

/// HyperKycResult enum will state whether the hyperkyc flow was success or cancelled or failure.
enum Status {
  /// Success state
  success,

  /// Failure state
  failure,

  /// Cancelled state
  cancelled,
}

/// HyperKycResult contains the result from the HyperKyc workflow
class HyperKycResult {
  /// State whether the hyperkyc flow was success or cancelled or failure.
  final Status? status;

  /// HyperKycData will contain partial or the final result data based on the result state.
  final HyperKycData? hyperKYCData;

  /// State what was the error (if any) during the hyperkyc flow
  final String? reason;

  /// Constructor
  HyperKycResult({
    this.status,
    this.hyperKYCData,
    this.reason,
  });

  /// Convert HyperKycResult object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.status: this.status?.name,
      HyperKycConstants.hyperKYCData: this.hyperKYCData,
      HyperKycConstants.reason: this.reason,
    };
  }

  /// Convert Map to HyperKycResult object
  factory HyperKycResult.fromMap(Map<dynamic, dynamic> map) {
    Status hyperKycResultEnum = Status.failure;
    if (map[HyperKycConstants.status] != null) {
      String resultEnumString = map[HyperKycConstants.status];
      switch (resultEnumString) {
        case HyperKycConstants.success:
          hyperKycResultEnum = Status.success;
          break;
        case HyperKycConstants.cancelled:
          hyperKycResultEnum = Status.cancelled;
          break;
        case HyperKycConstants.failure:
          hyperKycResultEnum = Status.failure;
          break;
      }
    }
    return HyperKycResult(
      status: hyperKycResultEnum,
      hyperKYCData:
          HyperKycData.fromMap(map[HyperKycConstants.hyperKYCData] ?? {}),
      reason: map[HyperKycConstants.reason] as String?,
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'HyperKycResult{status: $status, hyperKYCData: $hyperKYCData, reason: $reason}';
  }
}

==> 0.2.0.tar.gz: lib/hyperkyc_result.dart <==
import 'package:hyperkyc_flutter/hyperkyc_flutter_constants.dart';

import 'hyperkyc_data.dart';

/// [HyperKycResult] enum will state whether the hyperkyc flow was success or cancelled or failure.
enum Status {
  /// Success state
  success,

  /// Failure state
  failure,

  /// Cancelled state
  cancelled,
}

/// [HyperKycResult] contains the result from the HyperKyc workflow
class HyperKycResult {
  /// State whether the hyperkyc flow was success or cancelled or failure.
  final Status? status;

  /// Status of the application when HyperKyc flow is successful
  final String? applicationStatus;

  /// HyperKycData will contain partial or the final result data based on the result state.
  final HyperKycData? hyperKYCData;

  /// State what was the error (if any) during the hyperkyc flow
  final String? reason;

  /// Constructor
  HyperKycResult({
    this.status,
    this.applicationStatus,
    this.hyperKYCData,
    this.reason,
  });

  /// Convert HyperKycResult object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.status: this.status?.name,
      HyperKycConstants.applicationStatus: this.applicationStatus,
      HyperKycConstants.hyperKYCData: this.hyperKYCData,
      HyperKycConstants.reason: this.reason,
    };
  }

  /// Convert Map to HyperKycResult object
  factory HyperKycResult.fromMap(Map<dynamic, dynamic> map) {
    Status hyperKycResultEnum = Status.failure;
    if (map[HyperKycConstants.status] != null) {
      String resultEnumString = map[HyperKycConstants.status];
      switch (resultEnumString) {
        case HyperKycConstants.success:
          hyperKycResultEnum = Status.success;
          break;
        case HyperKycConstants.cancelled:
          hyperKycResultEnum = Status.cancelled;
          break;
        case HyperKycConstants.failure:
          hyperKycResultEnum = Status.failure;
          break;
      }
    }
    return HyperKycResult(
      status: hyperKycResultEnum,
      applicationStatus: map[HyperKycConstants.applicationStatus] as String?,
      hyperKYCData:
          HyperKycData.fromMap(map[HyperKycConstants.hyperKYCData] ?? {}),
      reason: map[HyperKycConstants.reason] as String?,
    );
  }

  /// Overriden [toString] method
  @override
  String toString() {
    return 'HyperKycResult{status: $status, applicationStatus: $applicationStatus, hyperKYCData: $hyperKYCData, reason: $reason}';
  }
}
